# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/entity_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/entity_type.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\017EntityTypeProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n7google/cloud/dialogflow_v2beta1/proto/entity_type.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xc8\x05\n\nEntityType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x43\n\x04kind\x18\x03 \x01(\x0e\x32\x30.google.cloud.dialogflow.v2beta1.EntityType.KindB\x03\xe0\x41\x02\x12_\n\x13\x61uto_expansion_mode\x18\x04 \x01(\x0e\x32=.google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionModeB\x03\xe0\x41\x01\x12I\n\x08\x65ntities\x18\x06 \x03(\x0b\x32\x32.google.cloud.dialogflow.v2beta1.EntityType.EntityB\x03\xe0\x41\x01\x12$\n\x17\x65nable_fuzzy_extraction\x18\x07 \x01(\x08\x42\x03\xe0\x41\x01\x1a)\n\x06\x45ntity\x12\r\n\x05value\x18\x01 \x01(\t\x12\x10\n\x08synonyms\x18\x02 \x03(\t"J\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x0c\n\x08KIND_MAP\x10\x01\x12\r\n\tKIND_LIST\x10\x02\x12\x0f\n\x0bKIND_REGEXP\x10\x03"Y\n\x11\x41utoExpansionMode\x12#\n\x1f\x41UTO_EXPANSION_MODE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UTO_EXPANSION_MODE_DEFAULT\x10\x01:\xa7\x01\xea\x41\xa3\x01\n$dialogflow.googleapis.com/EntityType\x12\x32projects/{project}/agent/entityTypes/{entity_type}\x12Gprojects/{project}/locations/{location}/agent/entityTypes/{entity_type}"\xa3\x01\n\x16ListEntityTypesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$dialogflow.googleapis.com/EntityType\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x16\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01"u\n\x17ListEntityTypesResponse\x12\x41\n\x0c\x65ntity_types\x18\x01 \x03(\x0b\x32+.google.cloud.dialogflow.v2beta1.EntityType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"n\n\x14GetEntityTypeRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$dialogflow.googleapis.com/EntityType\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01"\xba\x01\n\x17\x43reateEntityTypeRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$dialogflow.googleapis.com/EntityType\x12\x45\n\x0b\x65ntity_type\x18\x02 \x01(\x0b\x32+.google.cloud.dialogflow.v2beta1.EntityTypeB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01"\xb2\x01\n\x17UpdateEntityTypeRequest\x12\x45\n\x0b\x65ntity_type\x18\x01 \x01(\x0b\x32+.google.cloud.dialogflow.v2beta1.EntityTypeB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x34\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"U\n\x17\x44\x65leteEntityTypeRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$dialogflow.googleapis.com/EntityType"\xbb\x02\n\x1d\x42\x61tchUpdateEntityTypesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$dialogflow.googleapis.com/EntityType\x12\x1f\n\x15\x65ntity_type_batch_uri\x18\x02 \x01(\tH\x00\x12T\n\x18\x65ntity_type_batch_inline\x18\x03 \x01(\x0b\x32\x30.google.cloud.dialogflow.v2beta1.EntityTypeBatchH\x00\x12\x1a\n\rlanguage_code\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x34\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01\x42\x13\n\x11\x65ntity_type_batch"c\n\x1e\x42\x61tchUpdateEntityTypesResponse\x12\x41\n\x0c\x65ntity_types\x18\x01 \x03(\x0b\x32+.google.cloud.dialogflow.v2beta1.EntityType"}\n\x1d\x42\x61tchDeleteEntityTypesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$dialogflow.googleapis.com/EntityType\x12\x1e\n\x11\x65ntity_type_names\x18\x02 \x03(\tB\x03\xe0\x41\x02"\xc1\x01\n\x1a\x42\x61tchCreateEntitiesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$dialogflow.googleapis.com/EntityType\x12I\n\x08\x65ntities\x18\x02 \x03(\x0b\x32\x32.google.cloud.dialogflow.v2beta1.EntityType.EntityB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01"\xf2\x01\n\x1a\x42\x61tchUpdateEntitiesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$dialogflow.googleapis.com/EntityType\x12I\n\x08\x65ntities\x18\x02 \x03(\x0b\x32\x32.google.cloud.dialogflow.v2beta1.EntityType.EntityB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x92\x01\n\x1a\x42\x61tchDeleteEntitiesRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$dialogflow.googleapis.com/EntityType\x12\x1a\n\rentity_values\x18\x02 \x03(\tB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01"T\n\x0f\x45ntityTypeBatch\x12\x41\n\x0c\x65ntity_types\x18\x01 \x03(\x0b\x32+.google.cloud.dialogflow.v2beta1.EntityType2\xae\x1b\n\x0b\x45ntityTypes\x12\x9b\x02\n\x0fListEntityTypes\x12\x37.google.cloud.dialogflow.v2beta1.ListEntityTypesRequest\x1a\x38.google.cloud.dialogflow.v2beta1.ListEntityTypesResponse"\x94\x01\x82\xd3\xe4\x93\x02n\x12./v2beta1/{parent=projects/*/agent}/entityTypesZ<\x12:/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes\xda\x41\x06parent\xda\x41\x14parent,language_code\x12\x86\x02\n\rGetEntityType\x12\x35.google.cloud.dialogflow.v2beta1.GetEntityTypeRequest\x1a+.google.cloud.dialogflow.v2beta1.EntityType"\x90\x01\x82\xd3\xe4\x93\x02n\x12./v2beta1/{name=projects/*/agent/entityTypes/*}Z<\x12:/v2beta1/{name=projects/*/locations/*/agent/entityTypes/*}\xda\x41\x04name\xda\x41\x12name,language_code\x12\xc3\x02\n\x10\x43reateEntityType\x12\x38.google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest\x1a+.google.cloud.dialogflow.v2beta1.EntityType"\xc7\x01\x82\xd3\xe4\x93\x02\x88\x01"./v2beta1/{parent=projects/*/agent}/entityTypes:\x0b\x65ntity_typeZI":/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:\x0b\x65ntity_type\xda\x41\x12parent,entity_type\xda\x41 parent,entity_type,language_code\x12\xf5\x02\n\x10UpdateEntityType\x12\x38.google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest\x1a+.google.cloud.dialogflow.v2beta1.EntityType"\xf9\x01\x82\xd3\xe4\x93\x02\xa0\x01\x32:/v2beta1/{entity_type.name=projects/*/agent/entityTypes/*}:\x0b\x65ntity_typeZU2F/v2beta1/{entity_type.name=projects/*/locations/*/agent/entityTypes/*}:\x0b\x65ntity_type\xda\x41\x0b\x65ntity_type\xda\x41\x19\x65ntity_type,language_code\xda\x41%entity_type,language_code,update_mask\x12\xe1\x01\n\x10\x44\x65leteEntityType\x12\x38.google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest\x1a\x16.google.protobuf.Empty"{\x82\xd3\xe4\x93\x02n*./v2beta1/{name=projects/*/agent/entityTypes/*}Z<*:/v2beta1/{name=projects/*/locations/*/agent/entityTypes/*}\xda\x41\x04name\x12\xe8\x02\n\x16\x42\x61tchUpdateEntityTypes\x12>.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest\x1a\x1d.google.longrunning.Operation"\xee\x01\x82\xd3\xe4\x93\x02\x8c\x01":/v2beta1/{parent=projects/*/agent}/entityTypes:batchUpdate:\x01*ZK"F/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:batchUpdate:\x01*\xca\x41X\n>google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse\x12\x16google.protobuf.Struct\x12\xda\x02\n\x16\x42\x61tchDeleteEntityTypes\x12>.google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest\x1a\x1d.google.longrunning.Operation"\xe0\x01\x82\xd3\xe4\x93\x02\x8c\x01":/v2beta1/{parent=projects/*/agent}/entityTypes:batchDelete:\x01*ZK"F/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:batchDelete:\x01*\xda\x41\x18parent,entity_type_names\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\x81\x03\n\x13\x42\x61tchCreateEntities\x12;.google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest\x1a\x1d.google.longrunning.Operation"\x8d\x02\x82\xd3\xe4\x93\x02\xa2\x01"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchCreate:\x01*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchCreate:\x01*\xda\x41\x0fparent,entities\xda\x41\x1dparent,entities,language_code\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\x81\x03\n\x13\x42\x61tchUpdateEntities\x12;.google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest\x1a\x1d.google.longrunning.Operation"\x8d\x02\x82\xd3\xe4\x93\x02\xa2\x01"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchUpdate:\x01*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchUpdate:\x01*\xda\x41\x0fparent,entities\xda\x41\x1dparent,entities,language_code\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\x8b\x03\n\x13\x42\x61tchDeleteEntities\x12;.google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest\x1a\x1d.google.longrunning.Operation"\x97\x02\x82\xd3\xe4\x93\x02\xa2\x01"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchDelete:\x01*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchDelete:\x01*\xda\x41\x14parent,entity_values\xda\x41"parent,entity_values,language_code\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xad\x01\n#com.google.cloud.dialogflow.v2beta1B\x0f\x45ntityTypeProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_ENTITYTYPE_KIND = _descriptor.EnumDescriptor(
    name="Kind",
    full_name="google.cloud.dialogflow.v2beta1.EntityType.Kind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="KIND_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="KIND_MAP",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="KIND_LIST",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="KIND_REGEXP",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=685,
    serialized_end=759,
)
_sym_db.RegisterEnumDescriptor(_ENTITYTYPE_KIND)

_ENTITYTYPE_AUTOEXPANSIONMODE = _descriptor.EnumDescriptor(
    name="AutoExpansionMode",
    full_name="google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="AUTO_EXPANSION_MODE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUTO_EXPANSION_MODE_DEFAULT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=761,
    serialized_end=850,
)
_sym_db.RegisterEnumDescriptor(_ENTITYTYPE_AUTOEXPANSIONMODE)


_ENTITYTYPE_ENTITY = _descriptor.Descriptor(
    name="Entity",
    full_name="google.cloud.dialogflow.v2beta1.EntityType.Entity",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.Entity.value",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="synonyms",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.Entity.synonyms",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=642,
    serialized_end=683,
)

_ENTITYTYPE = _descriptor.Descriptor(
    name="EntityType",
    full_name="google.cloud.dialogflow.v2beta1.EntityType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.kind",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="auto_expansion_mode",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.auto_expansion_mode",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.entities",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enable_fuzzy_extraction",
            full_name="google.cloud.dialogflow.v2beta1.EntityType.enable_fuzzy_extraction",
            index=5,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_ENTITYTYPE_ENTITY],
    enum_types=[_ENTITYTYPE_KIND, _ENTITYTYPE_AUTOEXPANSIONMODE],
    serialized_options=b"\352A\243\001\n$dialogflow.googleapis.com/EntityType\0222projects/{project}/agent/entityTypes/{entity_type}\022Gprojects/{project}/locations/{location}/agent/entityTypes/{entity_type}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=308,
    serialized_end=1020,
)


_LISTENTITYTYPESREQUEST = _descriptor.Descriptor(
    name="ListEntityTypesRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1023,
    serialized_end=1186,
)


_LISTENTITYTYPESRESPONSE = _descriptor.Descriptor(
    name="ListEntityTypesResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entity_types",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.entity_types",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1188,
    serialized_end=1305,
)


_GETENTITYTYPEREQUEST = _descriptor.Descriptor(
    name="GetEntityTypeRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetEntityTypeRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetEntityTypeRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.GetEntityTypeRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1307,
    serialized_end=1417,
)


_CREATEENTITYTYPEREQUEST = _descriptor.Descriptor(
    name="CreateEntityTypeRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type",
            full_name="google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.entity_type",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1420,
    serialized_end=1606,
)


_UPDATEENTITYTYPEREQUEST = _descriptor.Descriptor(
    name="UpdateEntityTypeRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entity_type",
            full_name="google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.entity_type",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1609,
    serialized_end=1787,
)


_DELETEENTITYTYPEREQUEST = _descriptor.Descriptor(
    name="DeleteEntityTypeRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1789,
    serialized_end=1874,
)


_BATCHUPDATEENTITYTYPESREQUEST = _descriptor.Descriptor(
    name="BatchUpdateEntityTypesRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type_batch_uri",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.entity_type_batch_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type_batch_inline",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.entity_type_batch_inline",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.language_code",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.update_mask",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="entity_type_batch",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.entity_type_batch",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1877,
    serialized_end=2192,
)


_BATCHUPDATEENTITYTYPESRESPONSE = _descriptor.Descriptor(
    name="BatchUpdateEntityTypesResponse",
    full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entity_types",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse.entity_types",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2194,
    serialized_end=2293,
)


_BATCHDELETEENTITYTYPESREQUEST = _descriptor.Descriptor(
    name="BatchDeleteEntityTypesRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type_names",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest.entity_type_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2295,
    serialized_end=2420,
)


_BATCHCREATEENTITIESREQUEST = _descriptor.Descriptor(
    name="BatchCreateEntitiesRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities",
            full_name="google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.entities",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2423,
    serialized_end=2616,
)


_BATCHUPDATEENTITIESREQUEST = _descriptor.Descriptor(
    name="BatchUpdateEntitiesRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entities",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.entities",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.update_mask",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2619,
    serialized_end=2861,
)


_BATCHDELETEENTITIESREQUEST = _descriptor.Descriptor(
    name="BatchDeleteEntitiesRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$dialogflow.googleapis.com/EntityType",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_values",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.entity_values",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2864,
    serialized_end=3010,
)


_ENTITYTYPEBATCH = _descriptor.Descriptor(
    name="EntityTypeBatch",
    full_name="google.cloud.dialogflow.v2beta1.EntityTypeBatch",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entity_types",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypeBatch.entity_types",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3012,
    serialized_end=3096,
)

_ENTITYTYPE_ENTITY.containing_type = _ENTITYTYPE
_ENTITYTYPE.fields_by_name["kind"].enum_type = _ENTITYTYPE_KIND
_ENTITYTYPE.fields_by_name[
    "auto_expansion_mode"
].enum_type = _ENTITYTYPE_AUTOEXPANSIONMODE
_ENTITYTYPE.fields_by_name["entities"].message_type = _ENTITYTYPE_ENTITY
_ENTITYTYPE_KIND.containing_type = _ENTITYTYPE
_ENTITYTYPE_AUTOEXPANSIONMODE.containing_type = _ENTITYTYPE
_LISTENTITYTYPESRESPONSE.fields_by_name["entity_types"].message_type = _ENTITYTYPE
_CREATEENTITYTYPEREQUEST.fields_by_name["entity_type"].message_type = _ENTITYTYPE
_UPDATEENTITYTYPEREQUEST.fields_by_name["entity_type"].message_type = _ENTITYTYPE
_UPDATEENTITYTYPEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name[
    "entity_type_batch_inline"
].message_type = _ENTITYTYPEBATCH
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_BATCHUPDATEENTITYTYPESREQUEST.oneofs_by_name["entity_type_batch"].fields.append(
    _BATCHUPDATEENTITYTYPESREQUEST.fields_by_name["entity_type_batch_uri"]
)
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name[
    "entity_type_batch_uri"
].containing_oneof = _BATCHUPDATEENTITYTYPESREQUEST.oneofs_by_name["entity_type_batch"]
_BATCHUPDATEENTITYTYPESREQUEST.oneofs_by_name["entity_type_batch"].fields.append(
    _BATCHUPDATEENTITYTYPESREQUEST.fields_by_name["entity_type_batch_inline"]
)
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name[
    "entity_type_batch_inline"
].containing_oneof = _BATCHUPDATEENTITYTYPESREQUEST.oneofs_by_name["entity_type_batch"]
_BATCHUPDATEENTITYTYPESRESPONSE.fields_by_name[
    "entity_types"
].message_type = _ENTITYTYPE
_BATCHCREATEENTITIESREQUEST.fields_by_name["entities"].message_type = _ENTITYTYPE_ENTITY
_BATCHUPDATEENTITIESREQUEST.fields_by_name["entities"].message_type = _ENTITYTYPE_ENTITY
_BATCHUPDATEENTITIESREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ENTITYTYPEBATCH.fields_by_name["entity_types"].message_type = _ENTITYTYPE
DESCRIPTOR.message_types_by_name["EntityType"] = _ENTITYTYPE
DESCRIPTOR.message_types_by_name["ListEntityTypesRequest"] = _LISTENTITYTYPESREQUEST
DESCRIPTOR.message_types_by_name["ListEntityTypesResponse"] = _LISTENTITYTYPESRESPONSE
DESCRIPTOR.message_types_by_name["GetEntityTypeRequest"] = _GETENTITYTYPEREQUEST
DESCRIPTOR.message_types_by_name["CreateEntityTypeRequest"] = _CREATEENTITYTYPEREQUEST
DESCRIPTOR.message_types_by_name["UpdateEntityTypeRequest"] = _UPDATEENTITYTYPEREQUEST
DESCRIPTOR.message_types_by_name["DeleteEntityTypeRequest"] = _DELETEENTITYTYPEREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchUpdateEntityTypesRequest"
] = _BATCHUPDATEENTITYTYPESREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchUpdateEntityTypesResponse"
] = _BATCHUPDATEENTITYTYPESRESPONSE
DESCRIPTOR.message_types_by_name[
    "BatchDeleteEntityTypesRequest"
] = _BATCHDELETEENTITYTYPESREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchCreateEntitiesRequest"
] = _BATCHCREATEENTITIESREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchUpdateEntitiesRequest"
] = _BATCHUPDATEENTITIESREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchDeleteEntitiesRequest"
] = _BATCHDELETEENTITIESREQUEST
DESCRIPTOR.message_types_by_name["EntityTypeBatch"] = _ENTITYTYPEBATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EntityType = _reflection.GeneratedProtocolMessageType(
    "EntityType",
    (_message.Message,),
    {
        "Entity": _reflection.GeneratedProtocolMessageType(
            "Entity",
            (_message.Message,),
            {
                "DESCRIPTOR": _ENTITYTYPE_ENTITY,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
                "__doc__": """An **entity entry** for an associated entity type.
    
    Attributes:
        value:
            Required. The primary value associated with this entity entry.
            For example, if the entity type is *vegetable*, the value
            could be *scallions*.  For ``KIND_MAP`` entity types:  -  A
            reference value to be used in place of synonyms.  For
            ``KIND_LIST`` entity types:  -  A string that can contain
            references to other entity types (with or    without aliases).
        synonyms:
            Required. A collection of value synonyms. For example, if the
            entity type is *vegetable*, and ``value`` is *scallions*, a
            synonym could be *green onions*.  For ``KIND_LIST`` entity
            types:  -  This collection must contain exactly one synonym
            equal to ``value``.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.EntityType.Entity)
            },
        ),
        "DESCRIPTOR": _ENTITYTYPE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """Each intent parameter has a type, called the entity type, which
  dictates exactly how data from an end-user expression is extracted.
  Dialogflow provides predefined system entities that can match many
  common types of data. For example, there are system entities for
  matching dates, times, colors, email addresses, and so on. You can
  also create your own custom entities for matching custom data. For
  example, you could define a vegetable entity that can match the types
  of vegetables available for purchase with a grocery store agent.  For
  more information, see the `Entity guide
  <https://cloud.google.com/dialogflow/docs/entities-overview>`__.
  
  Attributes:
      name:
          The unique identifier of the entity type. Required for [Entity
          Types.UpdateEntityType][google.cloud.dialogflow.v2beta1.Entity
          Types.UpdateEntityType] and [EntityTypes.BatchUpdateEntityType
          s][google.cloud.dialogflow.v2beta1.EntityTypes.BatchUpdateEnti
          tyTypes] methods. Format: ``projects/<Project
          ID>/agent/entityTypes/<Entity Type ID>``.
      display_name:
          Required. The name of the entity type.
      kind:
          Required. Indicates the kind of entity type.
      auto_expansion_mode:
          Optional. Indicates whether the entity type can be
          automatically expanded.
      entities:
          Optional. The collection of entity entries associated with the
          entity type.
      enable_fuzzy_extraction:
          Optional. Enables fuzzy entity extraction during
          classification.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.EntityType)
    },
)
_sym_db.RegisterMessage(EntityType)
_sym_db.RegisterMessage(EntityType.Entity)

ListEntityTypesRequest = _reflection.GeneratedProtocolMessageType(
    "ListEntityTypesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTITYTYPESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.ListEntityTypes][google.cloud.dia
  logflow.v2beta1.EntityTypes.ListEntityTypes].
  
  Attributes:
      parent:
          Required. The agent to list all entity types from. Format:
          ``projects/<Project ID>/agent``.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListEntityTypesRequest)
    },
)
_sym_db.RegisterMessage(ListEntityTypesRequest)

ListEntityTypesResponse = _reflection.GeneratedProtocolMessageType(
    "ListEntityTypesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTITYTYPESRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The response message for [EntityTypes.ListEntityTypes][google.cloud.di
  alogflow.v2beta1.EntityTypes.ListEntityTypes].
  
  Attributes:
      entity_types:
          The list of agent entity types. There will be a maximum number
          of items returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListEntityTypesResponse)
    },
)
_sym_db.RegisterMessage(ListEntityTypesResponse)

GetEntityTypeRequest = _reflection.GeneratedProtocolMessageType(
    "GetEntityTypeRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETENTITYTYPEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.GetEntityType][google.cloud.dialo
  gflow.v2beta1.EntityTypes.GetEntityType].
  
  Attributes:
      name:
          Required. The name of the entity type. Format:
          ``projects/<Project ID>/agent/entityTypes/<EntityType ID>``.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetEntityTypeRequest)
    },
)
_sym_db.RegisterMessage(GetEntityTypeRequest)

CreateEntityTypeRequest = _reflection.GeneratedProtocolMessageType(
    "CreateEntityTypeRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEENTITYTYPEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.CreateEntityType][google.cloud.di
  alogflow.v2beta1.EntityTypes.CreateEntityType].
  
  Attributes:
      parent:
          Required. The agent to create a entity type for. Format:
          ``projects/<Project ID>/agent``.
      entity_type:
          Required. The entity type to create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest)
    },
)
_sym_db.RegisterMessage(CreateEntityTypeRequest)

UpdateEntityTypeRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateEntityTypeRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEENTITYTYPEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.UpdateEntityType][google.cloud.di
  alogflow.v2beta1.EntityTypes.UpdateEntityType].
  
  Attributes:
      entity_type:
          Required. The entity type to update.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest)
    },
)
_sym_db.RegisterMessage(UpdateEntityTypeRequest)

DeleteEntityTypeRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteEntityTypeRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEENTITYTYPEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.DeleteEntityType][google.cloud.di
  alogflow.v2beta1.EntityTypes.DeleteEntityType].
  
  Attributes:
      name:
          Required. The name of the entity type to delete. Format:
          ``projects/<Project ID>/agent/entityTypes/<EntityType ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest)
    },
)
_sym_db.RegisterMessage(DeleteEntityTypeRequest)

BatchUpdateEntityTypesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateEntityTypesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHUPDATEENTITYTYPESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.BatchUpdateEntityTypes][google.cl
  oud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntityTypes].
  
  Attributes:
      parent:
          Required. The name of the agent to update or create entity
          types in. Format: ``projects/<Project ID>/agent``.
      entity_type_batch:
          The source of the entity type batch.  For each entity type in
          the batch:  -  If ``name`` is specified, we update an existing
          entity type. -  If ``name`` is not specified, we create a new
          entity type.
      entity_type_batch_uri:
          The URI to a Google Cloud Storage file containing entity types
          to update or create. The file format can either be a
          serialized proto (of EntityBatch type) or a JSON object. Note:
          The URI must start with “gs://”.
      entity_type_batch_inline:
          The collection of entity types to update or create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest)
    },
)
_sym_db.RegisterMessage(BatchUpdateEntityTypesRequest)

BatchUpdateEntityTypesResponse = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateEntityTypesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHUPDATEENTITYTYPESRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The response message for [EntityTypes.BatchUpdateEntityTypes][google.c
  loud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntityTypes].
  
  Attributes:
      entity_types:
          The collection of updated or created entity types.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse)
    },
)
_sym_db.RegisterMessage(BatchUpdateEntityTypesResponse)

BatchDeleteEntityTypesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchDeleteEntityTypesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHDELETEENTITYTYPESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.BatchDeleteEntityTypes][google.cl
  oud.dialogflow.v2beta1.EntityTypes.BatchDeleteEntityTypes].
  
  Attributes:
      parent:
          Required. The name of the agent to delete all entities types
          for. Format: ``projects/<Project ID>/agent``.
      entity_type_names:
          Required. The names entity types to delete. All names must
          point to the same agent as ``parent``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest)
    },
)
_sym_db.RegisterMessage(BatchDeleteEntityTypesRequest)

BatchCreateEntitiesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchCreateEntitiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHCREATEENTITIESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.BatchCreateEntities][google.cloud
  .dialogflow.v2beta1.EntityTypes.BatchCreateEntities].
  
  Attributes:
      parent:
          Required. The name of the entity type to create entities in.
          Format: ``projects/<Project ID>/agent/entityTypes/<Entity Type
          ID>``.
      entities:
          Required. The entities to create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest)
    },
)
_sym_db.RegisterMessage(BatchCreateEntitiesRequest)

BatchUpdateEntitiesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateEntitiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHUPDATEENTITIESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.BatchUpdateEntities][google.cloud
  .dialogflow.v2beta1.EntityTypes.BatchUpdateEntities].
  
  Attributes:
      parent:
          Required. The name of the entity type to update or create
          entities in. Format: ``projects/<Project
          ID>/agent/entityTypes/<Entity Type ID>``.
      entities:
          Required. The entities to update or create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest)
    },
)
_sym_db.RegisterMessage(BatchUpdateEntitiesRequest)

BatchDeleteEntitiesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchDeleteEntitiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHDELETEENTITIESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """The request message for [EntityTypes.BatchDeleteEntities][google.cloud
  .dialogflow.v2beta1.EntityTypes.BatchDeleteEntities].
  
  Attributes:
      parent:
          Required. The name of the entity type to delete entries for.
          Format: ``projects/<Project ID>/agent/entityTypes/<Entity Type
          ID>``.
      entity_values:
          Required. The reference ``values`` of the entities to delete.
          Note that these are not fully-qualified names, i.e. they don’t
          start with ``projects/<Project ID>``.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest)
    },
)
_sym_db.RegisterMessage(BatchDeleteEntitiesRequest)

EntityTypeBatch = _reflection.GeneratedProtocolMessageType(
    "EntityTypeBatch",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTITYTYPEBATCH,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.entity_type_pb2",
        "__doc__": """This message is a wrapper around a collection of entity types.
  
  Attributes:
      entity_types:
          A collection of entity types.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.EntityTypeBatch)
    },
)
_sym_db.RegisterMessage(EntityTypeBatch)


DESCRIPTOR._options = None
_ENTITYTYPE.fields_by_name["display_name"]._options = None
_ENTITYTYPE.fields_by_name["kind"]._options = None
_ENTITYTYPE.fields_by_name["auto_expansion_mode"]._options = None
_ENTITYTYPE.fields_by_name["entities"]._options = None
_ENTITYTYPE.fields_by_name["enable_fuzzy_extraction"]._options = None
_ENTITYTYPE._options = None
_LISTENTITYTYPESREQUEST.fields_by_name["parent"]._options = None
_LISTENTITYTYPESREQUEST.fields_by_name["language_code"]._options = None
_LISTENTITYTYPESREQUEST.fields_by_name["page_size"]._options = None
_LISTENTITYTYPESREQUEST.fields_by_name["page_token"]._options = None
_GETENTITYTYPEREQUEST.fields_by_name["name"]._options = None
_GETENTITYTYPEREQUEST.fields_by_name["language_code"]._options = None
_CREATEENTITYTYPEREQUEST.fields_by_name["parent"]._options = None
_CREATEENTITYTYPEREQUEST.fields_by_name["entity_type"]._options = None
_CREATEENTITYTYPEREQUEST.fields_by_name["language_code"]._options = None
_UPDATEENTITYTYPEREQUEST.fields_by_name["entity_type"]._options = None
_UPDATEENTITYTYPEREQUEST.fields_by_name["language_code"]._options = None
_UPDATEENTITYTYPEREQUEST.fields_by_name["update_mask"]._options = None
_DELETEENTITYTYPEREQUEST.fields_by_name["name"]._options = None
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name["parent"]._options = None
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name["language_code"]._options = None
_BATCHUPDATEENTITYTYPESREQUEST.fields_by_name["update_mask"]._options = None
_BATCHDELETEENTITYTYPESREQUEST.fields_by_name["parent"]._options = None
_BATCHDELETEENTITYTYPESREQUEST.fields_by_name["entity_type_names"]._options = None
_BATCHCREATEENTITIESREQUEST.fields_by_name["parent"]._options = None
_BATCHCREATEENTITIESREQUEST.fields_by_name["entities"]._options = None
_BATCHCREATEENTITIESREQUEST.fields_by_name["language_code"]._options = None
_BATCHUPDATEENTITIESREQUEST.fields_by_name["parent"]._options = None
_BATCHUPDATEENTITIESREQUEST.fields_by_name["entities"]._options = None
_BATCHUPDATEENTITIESREQUEST.fields_by_name["language_code"]._options = None
_BATCHDELETEENTITIESREQUEST.fields_by_name["parent"]._options = None
_BATCHDELETEENTITIESREQUEST.fields_by_name["entity_values"]._options = None
_BATCHDELETEENTITIESREQUEST.fields_by_name["language_code"]._options = None

_ENTITYTYPES = _descriptor.ServiceDescriptor(
    name="EntityTypes",
    full_name="google.cloud.dialogflow.v2beta1.EntityTypes",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=3099,
    serialized_end=6601,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListEntityTypes",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.ListEntityTypes",
            index=0,
            containing_service=None,
            input_type=_LISTENTITYTYPESREQUEST,
            output_type=_LISTENTITYTYPESRESPONSE,
            serialized_options=b"\202\323\344\223\002n\022./v2beta1/{parent=projects/*/agent}/entityTypesZ<\022:/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes\332A\006parent\332A\024parent,language_code",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetEntityType",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.GetEntityType",
            index=1,
            containing_service=None,
            input_type=_GETENTITYTYPEREQUEST,
            output_type=_ENTITYTYPE,
            serialized_options=b"\202\323\344\223\002n\022./v2beta1/{name=projects/*/agent/entityTypes/*}Z<\022:/v2beta1/{name=projects/*/locations/*/agent/entityTypes/*}\332A\004name\332A\022name,language_code",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateEntityType",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.CreateEntityType",
            index=2,
            containing_service=None,
            input_type=_CREATEENTITYTYPEREQUEST,
            output_type=_ENTITYTYPE,
            serialized_options=b'\202\323\344\223\002\210\001"./v2beta1/{parent=projects/*/agent}/entityTypes:\013entity_typeZI":/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:\013entity_type\332A\022parent,entity_type\332A parent,entity_type,language_code',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateEntityType",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.UpdateEntityType",
            index=3,
            containing_service=None,
            input_type=_UPDATEENTITYTYPEREQUEST,
            output_type=_ENTITYTYPE,
            serialized_options=b"\202\323\344\223\002\240\0012:/v2beta1/{entity_type.name=projects/*/agent/entityTypes/*}:\013entity_typeZU2F/v2beta1/{entity_type.name=projects/*/locations/*/agent/entityTypes/*}:\013entity_type\332A\013entity_type\332A\031entity_type,language_code\332A%entity_type,language_code,update_mask",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteEntityType",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.DeleteEntityType",
            index=4,
            containing_service=None,
            input_type=_DELETEENTITYTYPEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002n*./v2beta1/{name=projects/*/agent/entityTypes/*}Z<*:/v2beta1/{name=projects/*/locations/*/agent/entityTypes/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchUpdateEntityTypes",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntityTypes",
            index=5,
            containing_service=None,
            input_type=_BATCHUPDATEENTITYTYPESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\214\001":/v2beta1/{parent=projects/*/agent}/entityTypes:batchUpdate:\001*ZK"F/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:batchUpdate:\001*\312AX\n>google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchDeleteEntityTypes",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.BatchDeleteEntityTypes",
            index=6,
            containing_service=None,
            input_type=_BATCHDELETEENTITYTYPESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\214\001":/v2beta1/{parent=projects/*/agent}/entityTypes:batchDelete:\001*ZK"F/v2beta1/{parent=projects/*/locations/*/agent}/entityTypes:batchDelete:\001*\332A\030parent,entity_type_names\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchCreateEntities",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.BatchCreateEntities",
            index=7,
            containing_service=None,
            input_type=_BATCHCREATEENTITIESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\242\001"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchCreate:\001*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchCreate:\001*\332A\017parent,entities\332A\035parent,entities,language_code\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchUpdateEntities",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntities",
            index=8,
            containing_service=None,
            input_type=_BATCHUPDATEENTITIESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\242\001"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchUpdate:\001*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchUpdate:\001*\332A\017parent,entities\332A\035parent,entities,language_code\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchDeleteEntities",
            full_name="google.cloud.dialogflow.v2beta1.EntityTypes.BatchDeleteEntities",
            index=9,
            containing_service=None,
            input_type=_BATCHDELETEENTITIESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\242\001"E/v2beta1/{parent=projects/*/agent/entityTypes/*}/entities:batchDelete:\001*ZV"Q/v2beta1/{parent=projects/*/locations/*/agent/entityTypes/*}/entities:batchDelete:\001*\332A\024parent,entity_values\332A"parent,entity_values,language_code\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ENTITYTYPES)

DESCRIPTOR.services_by_name["EntityTypes"] = _ENTITYTYPES

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers
import google.api_core.operations_v1

from dialogflow_v2.proto import agent_pb2_grpc


class AgentsGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.dialogflow.v2 Agents API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/dialogflow",
    )

    def __init__(
        self, channel=None, credentials=None, address="dialogflow.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
                options={
                    "grpc.max_send_message_length": -1,
                    "grpc.max_receive_message_length": -1,
                }.items(),
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {"agents_stub": agent_pb2_grpc.AgentsStub(channel)}

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(
            channel
        )

    @classmethod
    def create_channel(
        cls, address="dialogflow.googleapis.com:443", credentials=None, **kwargs
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES, **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def get_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.get_agent`.

        Retrieves the specified agent.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].GetAgent

    @property
    def set_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.set_agent`.

        Creates/updates the specified agent.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].SetAgent

    @property
    def delete_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.delete_agent`.

        Deletes the specified agent.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].DeleteAgent

    @property
    def search_agents(self):
        """Return the gRPC stub for :meth:`AgentsClient.search_agents`.

        Returns the list of agents.

        Since there is at most one conversational agent per project, this method
        is useful primarily for listing all agents across projects the caller
        has access to. One can achieve that with a wildcard project collection
        id "-". Refer to `List
        Sub-Collections <https://cloud.google.com/apis/design/design_patterns#list_sub-collections>`__.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].SearchAgents

    @property
    def train_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.train_agent`.

        Trains the specified agent.

        Operation <response: ``google.protobuf.Empty``>

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].TrainAgent

    @property
    def export_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.export_agent`.

        Exports the specified agent to a ZIP file.

        Operation <response: ``ExportAgentResponse``>

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].ExportAgent

    @property
    def import_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.import_agent`.

        Imports the specified agent from a ZIP file.

        Uploads new intents and entity types without deleting the existing ones.
        Intents and entity types with the same name are replaced with the new
        versions from ``ImportAgentRequest``. After the import, the imported
        draft agent will be trained automatically (unless disabled in agent
        settings). However, once the import is done, training may not be
        completed yet. Please call ``TrainAgent`` and wait for the operation it
        returns in order to train explicitly.

        Operation <response: ``google.protobuf.Empty``> An operation which
        tracks when importing is complete. It only tracks when the draft agent
        is updated not when it is done training.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].ImportAgent

    @property
    def restore_agent(self):
        """Return the gRPC stub for :meth:`AgentsClient.restore_agent`.

        Restores the specified agent from a ZIP file.

        Replaces the current agent version with a new one. All the intents and
        entity types in the older version are deleted. After the restore, the
        restored draft agent will be trained automatically (unless disabled in
        agent settings). However, once the restore is done, training may not be
        completed yet. Please call ``TrainAgent`` and wait for the operation it
        returns in order to train explicitly.

        Operation <response: ``google.protobuf.Empty``> An operation which
        tracks when restoring is complete. It only tracks when the draft agent
        is updated not when it is done training.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].RestoreAgent

    @property
    def get_validation_result(self):
        """Return the gRPC stub for :meth:`AgentsClient.get_validation_result`.

        Gets agent validation result. Agent validation is performed during
        training time and is updated automatically when training is completed.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["agents_stub"].GetValidationResult



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2/proto/validation_result.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2/proto/validation_result.proto",
    package="google.cloud.dialogflow.v2",
    syntax="proto3",
    serialized_options=b"\n\036com.google.cloud.dialogflow.v2B\025ValidationResultProtoP\001ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\370\001\001\242\002\002DF\252\002\032Google.Cloud.Dialogflow.V2",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n8google/cloud/dialogflow_v2/proto/validation_result.proto\x12\x1agoogle.cloud.dialogflow.v2\x1a\x1cgoogle/api/annotations.proto"\xd7\x01\n\x0fValidationError\x12\x46\n\x08severity\x18\x01 \x01(\x0e\x32\x34.google.cloud.dialogflow.v2.ValidationError.Severity\x12\x0f\n\x07\x65ntries\x18\x03 \x03(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t"T\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04"Z\n\x10ValidationResult\x12\x46\n\x11validation_errors\x18\x01 \x03(\x0b\x32+.google.cloud.dialogflow.v2.ValidationErrorB\xa4\x01\n\x1e\x63om.google.cloud.dialogflow.v2B\x15ValidationResultProtoP\x01ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1aGoogle.Cloud.Dialogflow.V2b\x06proto3',
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_VALIDATIONERROR_SEVERITY = _descriptor.EnumDescriptor(
    name="Severity",
    full_name="google.cloud.dialogflow.v2.ValidationError.Severity",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SEVERITY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INFO",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WARNING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ERROR",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CRITICAL",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=250,
    serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_VALIDATIONERROR_SEVERITY)


_VALIDATIONERROR = _descriptor.Descriptor(
    name="ValidationError",
    full_name="google.cloud.dialogflow.v2.ValidationError",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="severity",
            full_name="google.cloud.dialogflow.v2.ValidationError.severity",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="google.cloud.dialogflow.v2.ValidationError.entries",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="error_message",
            full_name="google.cloud.dialogflow.v2.ValidationError.error_message",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_VALIDATIONERROR_SEVERITY],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=119,
    serialized_end=334,
)


_VALIDATIONRESULT = _descriptor.Descriptor(
    name="ValidationResult",
    full_name="google.cloud.dialogflow.v2.ValidationResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="validation_errors",
            full_name="google.cloud.dialogflow.v2.ValidationResult.validation_errors",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=336,
    serialized_end=426,
)

_VALIDATIONERROR.fields_by_name["severity"].enum_type = _VALIDATIONERROR_SEVERITY
_VALIDATIONERROR_SEVERITY.containing_type = _VALIDATIONERROR
_VALIDATIONRESULT.fields_by_name["validation_errors"].message_type = _VALIDATIONERROR
DESCRIPTOR.message_types_by_name["ValidationError"] = _VALIDATIONERROR
DESCRIPTOR.message_types_by_name["ValidationResult"] = _VALIDATIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValidationError = _reflection.GeneratedProtocolMessageType(
    "ValidationError",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATIONERROR,
        "__module__": "google.cloud.dialogflow_v2.proto.validation_result_pb2",
        "__doc__": """Represents a single validation error.
  
  Attributes:
      severity:
          The severity of the error.
      entries:
          The names of the entries that the error is associated with.
          Format:  -  “projects//agent”, if the error is associated with
          the entire agent. -  “projects//agent/intents/”, if the error
          is associated with certain    intents. -
          “projects//agent/intents//trainingPhrases/”, if the error is
          associated with certain intent training phrases. -
          “projects//agent/intents//parameters/”, if the error is
          associated    with certain intent parameters. -
          “projects//agent/entities/”, if the error is associated with
          certain    entities.
      error_message:
          The detailed error messsage.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.ValidationError)
    },
)
_sym_db.RegisterMessage(ValidationError)

ValidationResult = _reflection.GeneratedProtocolMessageType(
    "ValidationResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATIONRESULT,
        "__module__": "google.cloud.dialogflow_v2.proto.validation_result_pb2",
        "__doc__": """Represents the output of agent validation.
  
  Attributes:
      validation_errors:
          Contains all validation errors.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.ValidationResult)
    },
)
_sym_db.RegisterMessage(ValidationResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/context.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/context.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\014ContextProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n3google/cloud/dialogflow_v2beta1/proto/context.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto"\x83\x03\n\x07\x43ontext\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0elifespan_count\x18\x02 \x01(\x05\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct:\xa4\x02\xea\x41\xa0\x02\n!dialogflow.googleapis.com/Context\x12>projects/{project}/agent/sessions/{session}/contexts/{context}\x12\x66projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}\x12Sprojects/{project}/locations/{location}/agent/sessions/{session}/contexts/{context}"w\n\x13ListContextsRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"k\n\x14ListContextsResponse\x12:\n\x08\x63ontexts\x18\x01 \x03(\x0b\x32(.google.cloud.dialogflow.v2beta1.Context\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"L\n\x11GetContextRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Context"\x91\x01\n\x14\x43reateContextRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context\x12>\n\x07\x63ontext\x18\x02 \x01(\x0b\x32(.google.cloud.dialogflow.v2beta1.ContextB\x03\xe0\x41\x02"\x8c\x01\n\x14UpdateContextRequest\x12>\n\x07\x63ontext\x18\x01 \x01(\x0b\x32(.google.cloud.dialogflow.v2beta1.ContextB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"O\n\x14\x44\x65leteContextRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Context"U\n\x18\x44\x65leteAllContextsRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context2\x9c\x16\n\x08\x43ontexts\x12\xba\x03\n\x0cListContexts\x12\x34.google.cloud.dialogflow.v2beta1.ListContextsRequest\x1a\x35.google.cloud.dialogflow.v2beta1.ListContextsResponse"\xbc\x02\x82\xd3\xe4\x93\x02\xac\x02\x12\x36/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO\x12M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD\x12\x42/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[\x12Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\xda\x41\x06parent\x12\xa7\x03\n\nGetContext\x12\x32.google.cloud.dialogflow.v2beta1.GetContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\xba\x02\x82\xd3\xe4\x93\x02\xac\x02\x12\x36/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO\x12M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD\x12\x42/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[\x12Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\xda\x41\x04name\x12\xdb\x03\n\rCreateContext\x12\x35.google.cloud.dialogflow.v2beta1.CreateContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\xe8\x02\x82\xd3\xe4\x93\x02\xd0\x02"6/v2beta1/{parent=projects/*/agent/sessions/*}/contexts:\x07\x63ontextZX"M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contexts:\x07\x63ontextZM"B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contexts:\x07\x63ontextZd"Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts:\x07\x63ontext\xda\x41\x0eparent,context\x12\x8a\x04\n\rUpdateContext\x12\x35.google.cloud.dialogflow.v2beta1.UpdateContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\x97\x03\x82\xd3\xe4\x93\x02\xf0\x02\x32>/v2beta1/{context.name=projects/*/agent/sessions/*/contexts/*}:\x07\x63ontextZ`2U/v2beta1/{context.name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}:\x07\x63ontextZU2J/v2beta1/{context.name=projects/*/locations/*/agent/sessions/*/contexts/*}:\x07\x63ontextZl2a/v2beta1/{context.name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}:\x07\x63ontext\xda\x41\x13\x63ontext,update_mask\xda\x41\x07\x63ontext\x12\x9b\x03\n\rDeleteContext\x12\x35.google.cloud.dialogflow.v2beta1.DeleteContextRequest\x1a\x16.google.protobuf.Empty"\xba\x02\x82\xd3\xe4\x93\x02\xac\x02*6/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO*M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD*B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[*Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\xda\x41\x04name\x12\xa5\x03\n\x11\x44\x65leteAllContexts\x12\x39.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest\x1a\x16.google.protobuf.Empty"\xbc\x02\x82\xd3\xe4\x93\x02\xac\x02*6/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO*M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD*B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[*Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\xda\x41\x06parent\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xaa\x01\n#com.google.cloud.dialogflow.v2beta1B\x0c\x43ontextProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
    ],
)


_CONTEXT = _descriptor.Descriptor(
    name="Context",
    full_name="google.cloud.dialogflow.v2beta1.Context",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Context.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lifespan_count",
            full_name="google.cloud.dialogflow.v2beta1.Context.lifespan_count",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.dialogflow.v2beta1.Context.parameters",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\240\002\n!dialogflow.googleapis.com/Context\022>projects/{project}/agent/sessions/{session}/contexts/{context}\022fprojects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}\022Sprojects/{project}/locations/{location}/agent/sessions/{session}/contexts/{context}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=297,
    serialized_end=684,
)


_LISTCONTEXTSREQUEST = _descriptor.Descriptor(
    name="ListContextsRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=686,
    serialized_end=805,
)


_LISTCONTEXTSRESPONSE = _descriptor.Descriptor(
    name="ListContextsResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="contexts",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse.contexts",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=807,
    serialized_end=914,
)


_GETCONTEXTREQUEST = _descriptor.Descriptor(
    name="GetContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetContextRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=916,
    serialized_end=992,
)


_CREATECONTEXTREQUEST = _descriptor.Descriptor(
    name="CreateContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=995,
    serialized_end=1140,
)


_UPDATECONTEXTREQUEST = _descriptor.Descriptor(
    name="UpdateContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="context",
            full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest.context",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1143,
    serialized_end=1283,
)


_DELETECONTEXTREQUEST = _descriptor.Descriptor(
    name="DeleteContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteContextRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1285,
    serialized_end=1364,
)


_DELETEALLCONTEXTSREQUEST = _descriptor.Descriptor(
    name="DeleteAllContextsRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1366,
    serialized_end=1451,
)

_CONTEXT.fields_by_name[
    "parameters"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LISTCONTEXTSRESPONSE.fields_by_name["contexts"].message_type = _CONTEXT
_CREATECONTEXTREQUEST.fields_by_name["context"].message_type = _CONTEXT
_UPDATECONTEXTREQUEST.fields_by_name["context"].message_type = _CONTEXT
_UPDATECONTEXTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["Context"] = _CONTEXT
DESCRIPTOR.message_types_by_name["ListContextsRequest"] = _LISTCONTEXTSREQUEST
DESCRIPTOR.message_types_by_name["ListContextsResponse"] = _LISTCONTEXTSRESPONSE
DESCRIPTOR.message_types_by_name["GetContextRequest"] = _GETCONTEXTREQUEST
DESCRIPTOR.message_types_by_name["CreateContextRequest"] = _CREATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["UpdateContextRequest"] = _UPDATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["DeleteContextRequest"] = _DELETECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["DeleteAllContextsRequest"] = _DELETEALLCONTEXTSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Context = _reflection.GeneratedProtocolMessageType(
    "Context",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONTEXT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """Dialogflow contexts are similar to natural language context. If a
  person says to you “they are orange”, you need context in order to
  understand what “they” is referring to. Similarly, for Dialogflow to
  handle an end-user expression like that, it needs to be provided with
  context in order to correctly match an intent.  Using contexts, you
  can control the flow of a conversation. You can configure contexts for
  an intent by setting input and output contexts, which are identified
  by string names. When an intent is matched, any configured output
  contexts for that intent become active. While any contexts are active,
  Dialogflow is more likely to match intents that are configured with
  input contexts that correspond to the currently active contexts.  For
  more information about context, see the `Contexts guide
  <https://cloud.google.com/dialogflow/docs/contexts-overview>`__.
  
  Attributes:
      name:
          Required. The unique identifier of the context. Format:
          ``projects/<Project ID>/agent/sessions/<Session
          ID>/contexts/<Context ID>``, or ``projects/<Project
          ID>/agent/environments/<Environment ID>/users/<User
          ID>/sessions/<Session ID>/contexts/<Context ID>``.  The
          ``Context ID`` is always converted to lowercase, may only
          contain characters in a-zA-Z0-9_-% and may be at most 250
          bytes long.  If ``Environment ID`` is not specified, we assume
          default ‘draft’ environment. If ``User ID`` is not specified,
          we assume default ‘-’ user.  The following context names are
          reserved for internal use by Dialogflow. You should not use
          these contexts or create contexts with these names:  -
          ``__system_counters__`` -  ``*_id_dialog_context`` -
          ``*_dialog_params_size``
      lifespan_count:
          Optional. The number of conversational query requests after
          which the context expires. The default is ``0``. If set to
          ``0``, the context expires immediately. Contexts expire
          automatically after 20 minutes if there are no matching
          queries.
      parameters:
          Optional. The collection of parameters associated with this
          context.  Depending on your protocol or client library
          language, this is a map, associative array, symbol table,
          dictionary, or JSON object composed of a collection of
          (MapKey, MapValue) pairs:  -  MapKey type: string -  MapKey
          value: parameter name -  MapValue type:     -  If parameter’s
          entity type is a composite entity: map    -  Else: string or
          number, depending on parameter value type  -  MapValue value:
          -  If parameter’s entity type is a composite entity: map from
          composite entity property names to property values    -  Else:
          parameter value
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Context)
    },
)
_sym_db.RegisterMessage(Context)

ListContextsRequest = _reflection.GeneratedProtocolMessageType(
    "ListContextsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTCONTEXTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.ListContexts][google.cloud.dialogflo
  w.v2beta1.Contexts.ListContexts].
  
  Attributes:
      parent:
          Required. The session to list all contexts from. Format:
          ``projects/<Project ID>/agent/sessions/<Session ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified, we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListContextsRequest)
    },
)
_sym_db.RegisterMessage(ListContextsRequest)

ListContextsResponse = _reflection.GeneratedProtocolMessageType(
    "ListContextsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTCONTEXTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The response message for [Contexts.ListContexts][google.cloud.dialogfl
  ow.v2beta1.Contexts.ListContexts].
  
  Attributes:
      contexts:
          The list of contexts. There will be a maximum number of items
          returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListContextsResponse)
    },
)
_sym_db.RegisterMessage(ListContextsResponse)

GetContextRequest = _reflection.GeneratedProtocolMessageType(
    "GetContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETCONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.GetContext][google.cloud.dialogflow.
  v2beta1.Contexts.GetContext].
  
  Attributes:
      name:
          Required. The name of the context. Format: ``projects/<Project
          ID>/agent/sessions/<Session ID>/contexts/<Context ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>/contexts/<Context
          ID>``. If ``Environment ID`` is not specified, we assume
          default ‘draft’ environment. If ``User ID`` is not specified,
          we assume default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetContextRequest)
    },
)
_sym_db.RegisterMessage(GetContextRequest)

CreateContextRequest = _reflection.GeneratedProtocolMessageType(
    "CreateContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.CreateContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.CreateContext].
  
  Attributes:
      parent:
          Required. The session to create a context for. Format:
          ``projects/<Project ID>/agent/sessions/<Session ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified, we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
      context:
          Required. The context to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateContextRequest)
    },
)
_sym_db.RegisterMessage(CreateContextRequest)

UpdateContextRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.UpdateContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.UpdateContext].
  
  Attributes:
      context:
          Required. The context to update.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateContextRequest)
    },
)
_sym_db.RegisterMessage(UpdateContextRequest)

DeleteContextRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.DeleteContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.DeleteContext].
  
  Attributes:
      name:
          Required. The name of the context to delete. Format:
          ``projects/<Project ID>/agent/sessions/<Session
          ID>/contexts/<Context ID>`` or ``projects/<Project
          ID>/agent/environments/<Environment ID>/users/<User
          ID>/sessions/<Session ID>/contexts/<Context ID>``. If
          ``Environment ID`` is not specified, we assume default ‘draft’
          environment. If ``User ID`` is not specified, we assume
          default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteContextRequest)
    },
)
_sym_db.RegisterMessage(DeleteContextRequest)

DeleteAllContextsRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteAllContextsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEALLCONTEXTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.DeleteAllContexts][google.cloud.dial
  ogflow.v2beta1.Contexts.DeleteAllContexts].
  
  Attributes:
      parent:
          Required. The name of the session to delete all contexts from.
          Format: ``projects/<Project ID>/agent/sessions/<Session ID>``
          or ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest)
    },
)
_sym_db.RegisterMessage(DeleteAllContextsRequest)


DESCRIPTOR._options = None
_CONTEXT._options = None
_LISTCONTEXTSREQUEST.fields_by_name["parent"]._options = None
_GETCONTEXTREQUEST.fields_by_name["name"]._options = None
_CREATECONTEXTREQUEST.fields_by_name["parent"]._options = None
_CREATECONTEXTREQUEST.fields_by_name["context"]._options = None
_UPDATECONTEXTREQUEST.fields_by_name["context"]._options = None
_UPDATECONTEXTREQUEST.fields_by_name["update_mask"]._options = None
_DELETECONTEXTREQUEST.fields_by_name["name"]._options = None
_DELETEALLCONTEXTSREQUEST.fields_by_name["parent"]._options = None

_CONTEXTS = _descriptor.ServiceDescriptor(
    name="Contexts",
    full_name="google.cloud.dialogflow.v2beta1.Contexts",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=1454,
    serialized_end=4298,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListContexts",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.ListContexts",
            index=0,
            containing_service=None,
            input_type=_LISTCONTEXTSREQUEST,
            output_type=_LISTCONTEXTSRESPONSE,
            serialized_options=b"\202\323\344\223\002\254\002\0226/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO\022M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD\022B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[\022Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.GetContext",
            index=1,
            containing_service=None,
            input_type=_GETCONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b"\202\323\344\223\002\254\002\0226/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO\022M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD\022B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[\022Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.CreateContext",
            index=2,
            containing_service=None,
            input_type=_CREATECONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b'\202\323\344\223\002\320\002"6/v2beta1/{parent=projects/*/agent/sessions/*}/contexts:\007contextZX"M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contexts:\007contextZM"B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contexts:\007contextZd"Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts:\007context\332A\016parent,context',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.UpdateContext",
            index=3,
            containing_service=None,
            input_type=_UPDATECONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b"\202\323\344\223\002\360\0022>/v2beta1/{context.name=projects/*/agent/sessions/*/contexts/*}:\007contextZ`2U/v2beta1/{context.name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}:\007contextZU2J/v2beta1/{context.name=projects/*/locations/*/agent/sessions/*/contexts/*}:\007contextZl2a/v2beta1/{context.name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}:\007context\332A\023context,update_mask\332A\007context",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.DeleteContext",
            index=4,
            containing_service=None,
            input_type=_DELETECONTEXTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\254\002*6/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO*M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD*B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[*Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteAllContexts",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.DeleteAllContexts",
            index=5,
            containing_service=None,
            input_type=_DELETEALLCONTEXTSREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\254\002*6/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO*M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD*B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[*Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_CONTEXTS)

DESCRIPTOR.services_by_name["Contexts"] = _CONTEXTS

# @@protoc_insertion_point(module_scope)
